"""
Relativictic Difference Scheme
Particle-in-Cell code (REDPIC) init file.

"""

from .constants import *

__version__ = '0.0.1'
__doc__ = '''Relativictic Difference Scheme
Particle-in-Cell code (REDPIC)'''

__all__ = constants.__all__
